@@ -1,6 +1,6 @@
 <?php
 /*
-  $Id: upcoming_products.php,v 1.1.9.1.2.2 2003/10/30 09:59:46 minami Exp $
+  $Id: upcoming_products.php,v 1.1.9.1.2.3 2003/12/08 09:26:51 shota Exp $
 
   osCommerce, Open Source E-Commerce Solutions
   http://www.oscommerce.com
@@ -9,8 +9,14 @@
 
   Released under the GNU General Public License
 */
+// max number of display item
+if(Dino_Browser::is_handy()){
+  $limit = MAX_DISPLAY_UPCOMING_PRODUCTS_MOBILE;
+} else {
+  $limit = MAX_DISPLAY_UPCOMING_PRODUCTS;
+}
 
-  $expected_query = tep_db_query("select p.products_id, pd.products_name, products_date_available as date_expected from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where to_days(products_date_available) >= to_days(now()) and p.products_id = pd.products_id and pd.language_id = '" . (int)$_SESSION["languages_id"] . "' order by " . EXPECTED_PRODUCTS_FIELD . " " . EXPECTED_PRODUCTS_SORT . " limit " . MAX_DISPLAY_UPCOMING_PRODUCTS);
+  $expected_query = tep_db_query("select p.products_id, pd.products_name, products_date_available as date_expected from " . TABLE_PRODUCTS . " p, " . TABLE_PRODUCTS_DESCRIPTION . " pd where to_days(products_date_available) >= to_days(now()) and p.products_id = pd.products_id and pd.language_id = '" . (int)$_SESSION["languages_id"] . "' order by " . EXPECTED_PRODUCTS_FIELD . " " . EXPECTED_PRODUCTS_SORT . " limit " . $limit);
   $this->assign('num_rows', tep_db_num_rows($expected_query));
   if (tep_db_num_rows($expected_query) > 0) {
     $row = 0;
